# callspect

Inspect program execution from data generated by `callspectpy`

```bash
# run app as background process
$ callspect ~/path-to-file-generated-by-callspectpy &
# open `callspect` in default browser and view data
$ xdg-open http://127.0.0.1:5000/
```


## TODO Future:

    * call args seperated with newlines as option
    * max/min window with app-header
    * layout customization
        * https://www.webcomponents.org/element/vaadin/vaadin-split-layout
        * https://www.webcomponents.org/element/kcmr/resizable-panels
        * should be reflected in link AND allow to change WITHOUT refresh
    * scr-code filename is floating
    * details-box: open-in-editor action
    * hidable left pane with (app-drawer)
        * show whole map flow with warning about too-many-calls
        * main-thread selected in call-tree shows all flow map?
            * limit actor parent calls?
            * limit actor child calls?
        * allow picked package to be shown (default all-checked?)
    * DX: files \*.css.html are shitty copy-paste from node_modules, there must be a better way
    * actor has zooming feature
        * show only module-level interaction
        * show only class-level interaction
        * show only obj-level interaction
        * show only function-level interaction
    * sequence svg reacts by highlighting in call-tree
        * https://developer.mozilla.org/en-US/docs/Web/SVG/Element/svg
    * additional vertical layout
    * diagram handles recurrent fn
